@@ -9,7 +9,7 @@ from ast import literal_eval
 
 from requests import Session
 from jdatetime import datetime as jdatetime
-from pandas import read_csv, to_numeric, DataFrame
+from pandas import read_csv, to_numeric, DataFrame, read_html
 
 
 strptime = datetime.strptime
@@ -38,6 +38,7 @@ INDEX_TIMESTAMP_MATCH = rc(r'(\d\d)/(\d+)/(\d+) (\d\d):(\d\d):(\d\d)').match
 
 with open(f'{__file__}/../ids.json', encoding='utf8') as f:
     KNOWN_IDS: dict[str, str] = load(f)
+KNOWN_IDS |= {v[0]: v for v in KNOWN_IDS.values()}
 
 
 def get_content(url) -> bytes:
@@ -57,7 +58,7 @@ class Instrument:
 
     def __init__(self, id: Union[int, str]):
         try:
-            self.id, self.l13, self.l18, self.isin = KNOWN_IDS[f'{id}']
+            self.id, self.l13, self.l18, self.isin = KNOWN_IDS[id]
         except KeyError:
             if isinstance(id, int):
                 self.id = id
@@ -191,6 +192,11 @@ class Instrument:
         )
         return df
 
+    def get_identification(self) -> DataFrame:
+        """Return the information available in the identification (شناسه) tab."""
+        text = fa_norm_text(f'http://www.tsetmc.com/Loader.aspx?Partree=15131M&i={self.id}')
+        return read_html(text, index_col=0)[0]
+
     @staticmethod
     def from_search(s: str) -> 'Instrument':
         """Look up the ID through a web search and return Instrument."""
